==> carbon-components-react-0.1.8.tgz: package/lib/components/SplitButton/SplitButton-test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _SplitButton = _interopRequireDefault(require("../SplitButton"));

var _OverflowMenuItem = _interopRequireDefault(require("../OverflowMenuItem"));

var _Button = _interopRequireDefault(require("../Button"));

var _OverflowMenu = _interopRequireDefault(require("../OverflowMenu"));

var _enzyme = require("enzyme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('SplitButton', function () {
  describe('renders as expected', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_SplitButton.default, {
      classNameContainer: 'extra-class',
      classNameButton: 'extra-class',
      classNameOverflow: 'extra-class'
    }, _react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 1'
    }), _react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 2',
      primaryFocus: true
    }), _react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 2'
    })));
    it('renders children as expected', function () {
      expect(wrapper.props().children.length).toEqual(2);
    });
    it('renders extra classes as expected', function () {
      expect(wrapper.hasClass('extra-class')).toEqual(true);
      expect(wrapper.find(_Button.default).shallow().hasClass('extra-class')).toEqual(true);
      expect(wrapper.find(_OverflowMenu.default).shallow().hasClass('extra-class')).toEqual(true);
    });
  });
});

==> carbon-components-react-0.8.1.tgz: package/lib/components/SplitButton/SplitButton-test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _SplitButton = _interopRequireDefault(require("../SplitButton"));

var _OverflowMenuItem = _interopRequireDefault(require("../OverflowMenuItem"));

var _Button = _interopRequireDefault(require("../Button"));

var _OverflowMenu = _interopRequireDefault(require("../OverflowMenu"));

var _enzyme = require("enzyme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('SplitButton', function () {
  describe('renders as expected', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_SplitButton.default, {
      classNameContainer: 'extra-class',
      classNameButton: 'extra-class',
      classNameOverflow: 'extra-class'
    }, /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 1'
    }), /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 2'
    }), /*#__PURE__*/_react.default.createElement(_OverflowMenuItem.default, {
      itemText: 'Item 2'
    })));
    it('renders children as expected', function () {
      expect(wrapper.props().children.length).toEqual(2);
    });
    it('renders extra classes as expected', function () {
      expect(wrapper.hasClass('extra-class')).toEqual(true);
      expect(wrapper.find(_Button.default).shallow().hasClass('extra-class')).toEqual(true);
      expect(wrapper.find(_OverflowMenu.default).shallow().hasClass('extra-class')).toEqual(true);
    });
  });
});
